ATM Protocol - Wire protocol for daemon communication
This crate provides message types and parsing for communication between Claude Code status scripts and the daemon, and between the daemon and TUI clients.
Re-exports
pub use message::ClientMessage;pub use message::DaemonMessage;pub use message::MessageType;pub use parse::RawContextWindow;pub use parse::RawCost;pub use parse::RawHookEvent;pub use parse::RawModel;pub use parse::RawStatusLine;pub use parse::RawWorkspace;pub use version::ProtocolVersion;